==> u_team_core-fabric-1.19.4-5.0.2.371-sources.jar: info/u_team/u_team_core/gui/elements/ScrollableListEntry.java <==
package info.u_team.u_team_core.gui.elements;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_310;
import net.minecraft.class_350;
import net.minecraft.class_364;
import net.minecraft.class_4280;
import net.minecraft.class_4587;

public abstract class ScrollableListEntry<T extends ScrollableListEntry<T>> extends class_4280.class_4281<T> {
	
	protected final class_310 minecraft;
	
	private final List<class_364> children;
	
	public ScrollableListEntry() {
		minecraft = class_310.method_1551();
		children = new ArrayList<>();
	}
	
	protected <B extends class_364> B addChildren(B listener) {
		children.add(listener);
		return listener;
	}
	
	@Override
	public boolean method_25402(double mouseX, double mouseY, int button) {
		children.forEach(listener -> listener.method_25402(mouseX, mouseY, button));
		return true;
	}
	
	@Override
	public boolean method_25406(double mouseX, double mouseY, int button) {
		for (final class_364 listener : children) {
			if (listener.method_25406(mouseX, mouseY, button)) {
				return true;
			}
		}
		return false;
	}
	
	@Override
	public boolean method_25403(double mouseX, double mouseY, int button, double dragX, double dragY) {
		for (final class_364 listener : children) {
			if (listener.method_25403(mouseX, mouseY, button, dragX, dragY)) {
				return true;
			}
		}
		return false;
	}
	
	@Override
	public abstract void method_25343(class_4587 poseStack, int index, int top, int left, int width, int height, int mouseX, int mouseY, boolean hovered, float partialTick);
	
	@SuppressWarnings("deprecation")
	protected class_350<T> getList() {
		return field_22752;
	}
}

==> u_team_core-fabric-1.20.1-5.1.4.382-sources.jar: info/u_team/u_team_core/gui/elements/ScrollableListEntry.java <==
package info.u_team.u_team_core.gui.elements;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_350;
import net.minecraft.class_364;
import net.minecraft.class_4280;

public abstract class ScrollableListEntry<T extends ScrollableListEntry<T>> extends class_4280.class_4281<T> {
	
	protected final class_310 minecraft;
	
	private final List<class_364> children;
	
	public ScrollableListEntry() {
		minecraft = class_310.method_1551();
		children = new ArrayList<>();
	}
	
	protected <B extends class_364> B addChildren(B listener) {
		children.add(listener);
		return listener;
	}
	
	@Override
	public boolean method_25402(double mouseX, double mouseY, int button) {
		children.forEach(listener -> listener.method_25402(mouseX, mouseY, button));
		return true;
	}
	
	@Override
	public boolean method_25406(double mouseX, double mouseY, int button) {
		for (final class_364 listener : children) {
			if (listener.method_25406(mouseX, mouseY, button)) {
				return true;
			}
		}
		return false;
	}
	
	@Override
	public boolean method_25403(double mouseX, double mouseY, int button, double dragX, double dragY) {
		for (final class_364 listener : children) {
			if (listener.method_25403(mouseX, mouseY, button, dragX, dragY)) {
				return true;
			}
		}
		return false;
	}
	
	@Override
	public abstract void method_25343(class_332 guiGraphics, int index, int top, int left, int width, int height, int mouseX, int mouseY, boolean hovered, float partialTick);
	
	@SuppressWarnings("deprecation")
	protected class_350<T> getList() {
		return field_22752;
	}
}
